@@ -92,13 +92,13 @@ def main():
     parser.add_argument("-ip", dest="ip", help="ip", default="192.168.2.251", required=False)
     args = parser.parse_args()
     ip = args.ip
-    print(ip)
 
     www_root = "/YUM/jenkins/"
-    original_update_center_json = "update-center.json"
+    original_update_center_json = "update-center-old.json"
     www_url = f"http://{ip}:81/jenkins"
     private_key = "update-center.key"
     public_key = "update-center.der"
+    print(www_url)
 
     # Load original update center
     with open(www_root + original_update_center_json, "r", encoding="utf-8") as fd:
